@@ -7,11 +7,13 @@ pub use crate::raw_message::{RawMessage, RawMessageDescription};
 pub use crate::rosmsg::RosMsg;
 pub use crate::singleton::*;
 pub use crate::tcpros::{Client, ClientResponse, Message, ServicePair};
-pub use crate::time::{Duration, Time};
+pub use dynamic_msg::DynamicMsg;
+pub use ros_message::{Duration, MessageValue as MsgMessage, Time, Value as MsgValue};
 #[doc(hidden)]
 pub use rosrust_codegen::*;
 
 pub mod api;
+mod dynamic_msg;
 mod log_macros;
 #[doc(hidden)]
 pub mod msg;
@@ -21,5 +23,4 @@ pub mod rosmsg;
 mod rosxmlrpc;
 pub mod singleton;
 mod tcpros;
-mod time;
 mod util;
