@@ -1,5 +1,4 @@
 use crossbeam::channel::unbounded;
-use rosrust;
 use std::process::Command;
 
 mod util;
@@ -30,8 +29,9 @@ fn publisher_to_rosrust_subscriber() {
 
     let publisher = rosrust::publish::<msg::std_msgs::String>("chatter", 100).unwrap();
 
-    let mut message = msg::std_msgs::String::default();
-    message.data = "hello world".to_owned();
+    let message = msg::std_msgs::String {
+        data: "hello world".into(),
+    };
 
     util::test_publisher(&publisher, &message, &rx, r"^Received: hello world$", 50);
 
